==> nextcloud-27.1.11.tgz: nextcloud/apps/serverinfo/l10n/ga.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Níl eolas LAP ar fáil",
    "Load average: {cpu} (last minute)" : "Meán luchtaithe: {cpu} (nóiméad deireanach)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Iomlán: {memTotalBytes}/Úsáid reatha: {memUsageBytes}",
    "RAM info not available" : "Níl eolas RAM ar fáil",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Iomlán: {swapTotalBytes}/Úsáid reatha: {swapUsageBytes}",
    "SWAP info not available" : "Níl eolas SWAP ar fáil",
    "Copied!" : "Cóipeáladh!",
    "Not supported!" : "Gan tacaíocht!",
    "Press ⌘-C to copy." : "Brúigh ⌘-C chun cóip a dhéanamh.",
    "Press Ctrl-C to copy." : "Brúigh Ctrl-C chun cóip a dhéanamh.",
    "System" : "Córas",
    "Monitoring" : "Monatóireacht",
    "Monitoring app with useful server information" : "Aip monatóireachta le faisnéis úsáideach freastalaí",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Soláthraíonn sé faisnéis úsáideach freastalaí, mar shampla ualach LAP, úsáid RAM, úsáid diosca, líon na n-úsáideoirí, etc.",
    "Operating System:" : "Córas oibriucháin:",
    "CPU:" : "LAP:",
    "Unknown Processor" : "Próiseálaí Anaithnid",
    "Memory:" : "Cuimhne:",
    "Server time:" : "Am freastalaí:",
    "Uptime:" : "Aga fónaimh:",
    "Temperature" : "Teocht",
    "Load" : "Luchtaigh",
    "Memory" : "Cuimhne",
    "Disk" : "Diosca",
    "Mount:" : "Gléasta:",
    "Filesystem:" : "Córas comhaid:",
    "Size:" : "Méid:",
    "Available:" : "Ar fáil:",
    "Used:" : "Úsáidte:",
    "Files:" : "Comhaid:",
    "Storages:" : "Stórais:",
    "Free Space:" : "Spás saor in aisce:",
    "Network" : "Líonra",
    "Hostname:" : "Ainm an ósta:",
    "Gateway:" : "Geata:",
    "Status:" : "Stádas:",
    "Speed:" : "Luas:",
    "Duplex:" : "Déphléacsacha:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Úsáideoirí gníomhacha",
    "Total users:" : "Úsáideoirí iomlána:",
    "24 hours:" : "24 uair:",
    "1 hour:" : "1 uair:",
    "5 mins:" : "5 nóim:",
    "Shares" : "Scaireanna",
    "Users:" : "Úsáideoirí:",
    "Groups:" : "Grúpaí:",
    "Links:" : "Naisc:",
    "Emails:" : "Ríomhphoist:",
    "Federated sent:" : "Seolta Cónaidhme:",
    "Federated received:" : "Fuair ​​​​cónaidhm:",
    "Talk conversations:" : "Comhráite:",
    "PHP" : "PHP",
    "Version:" : "Leagan:",
    "Memory limit:" : "Teorainn chuimhne:",
    "Max execution time:" : "Uasmhéid ama rite:",
    "Upload max size:" : "Uaslódáil méid uasta:",
    "OPcache Revalidate Frequency:" : "Minicíocht Athbhailíochtaithe OPcache:",
    "Extensions:" : "Eisínteachtaí:",
    "Unable to list extensions" : "Ní féidir na síntí a liostú",
    "Show phpinfo" : "Taispeáin phpinfo",
    "Database" : "Bunachar Sonraí",
    "Type:" : "Cineál:",
    "External monitoring tool" : "Uirlis sheachtrach monatóireachta",
    "Use this end point to connect an external monitoring tool:" : "Úsáid an pointe deiridh seo chun uirlis sheachtrach monatóireachta a nascadh:",
    "Copy" : "Cóipeáil",
    "Output in JSON" : "Aschur in JSON",
    "Skip server update" : "Léim ar nuashonrú an fhreastalaí",
    "To use an access token, please generate one then set it using the following command:" : "Chun comhartha rochtana a úsáid, giniúint ceann agus ansin socraigh é ag baint úsáide as an ordú seo a leanas le do thoil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ansin cuir an comhartha leis an gceanntásc \"NC-Token\" agus an URL thuas á cheistiú.",
    "DNS:" : "DNS:",
    "Skip app updates (including app updates will send an external request to the app store)" : "Léim ar nuashonruithe aipeanna (seolfaidh nuashonruithe aipeanna iarratas seachtrach chuig an siopa aip san áireamh)"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-28.0.8.tgz: nextcloud/apps/serverinfo/l10n/ga.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Níl eolas LAP ar fáil",
    "Load average: {cpu} (last minute)" : "Meán luchtaithe: {cpu} (nóiméad deireanach)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Iomlán: {memTotalBytes}/Úsáid reatha: {memUsageBytes}",
    "RAM info not available" : "Níl eolas RAM ar fáil",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Iomlán: {swapTotalBytes}/Úsáid reatha: {swapUsageBytes}",
    "SWAP info not available" : "Níl eolas SWAP ar fáil",
    "Copied!" : "Cóipeáladh!",
    "Not supported!" : "Gan tacaíocht!",
    "Press ⌘-C to copy." : "Brúigh ⌘-C chun cóip a dhéanamh.",
    "Press Ctrl-C to copy." : "Brúigh Ctrl-C chun cóip a dhéanamh.",
    "System" : "Córas",
    "Monitoring" : "Monatóireacht",
    "Monitoring app with useful server information" : "Aip monatóireachta le faisnéis úsáideach freastalaí",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Soláthraíonn sé faisnéis úsáideach freastalaí, mar shampla ualach LAP, úsáid RAM, úsáid diosca, líon na n-úsáideoirí, etc.",
    "Operating System:" : "Córas oibriucháin:",
    "CPU:" : "LAP:",
    "Unknown Processor" : "Próiseálaí Anaithnid",
    "Memory:" : "Cuimhne:",
    "Server time:" : "Am freastalaí:",
    "Uptime:" : "Aga fónaimh:",
    "Temperature" : "Teocht",
    "Load" : "Luchtaigh",
    "Memory" : "Cuimhne",
    "Disk" : "Diosca",
    "Mount:" : "Gléasta:",
    "Filesystem:" : "Córas comhaid:",
    "Size:" : "Méid:",
    "Available:" : "Ar fáil:",
    "Used:" : "Úsáidte:",
    "Files:" : "Comhaid:",
    "Storages:" : "Stórais:",
    "Free Space:" : "Spás saor in aisce:",
    "Network" : "Líonra",
    "Hostname:" : "Ainm an ósta:",
    "Gateway:" : "Geata:",
    "Status:" : "Stádas:",
    "Speed:" : "Luas:",
    "Duplex:" : "Déphléacsacha:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Úsáideoirí gníomhacha",
    "Total users:" : "Úsáideoirí iomlána:",
    "24 hours:" : "24 uair:",
    "1 hour:" : "1 uair:",
    "5 mins:" : "5 nóim:",
    "Shares" : "Scaireanna",
    "Users:" : "Úsáideoirí:",
    "Groups:" : "Grúpaí:",
    "Links:" : "Naisc:",
    "Emails:" : "Ríomhphoist:",
    "Federated sent:" : "Seolta Cónaidhme:",
    "Federated received:" : "Fuair ​​​​cónaidhm:",
    "Talk conversations:" : "Comhráite:",
    "PHP" : "PHP",
    "Version:" : "Leagan:",
    "Memory limit:" : "Teorainn chuimhne:",
    "Max execution time:" : "Uasmhéid ama rite:",
    "Upload max size:" : "Uaslódáil méid uasta:",
    "OPcache Revalidate Frequency:" : "Minicíocht Athbhailíochtaithe OPcache:",
    "Extensions:" : "Eisínteachtaí:",
    "Unable to list extensions" : "Ní féidir na síntí a liostú",
    "Show phpinfo" : "Taispeáin phpinfo",
    "Database" : "Bunachar Sonraí",
    "Type:" : "Cineál:",
    "External monitoring tool" : "Uirlis sheachtrach monatóireachta",
    "Use this end point to connect an external monitoring tool:" : "Úsáid an pointe deiridh seo chun uirlis sheachtrach monatóireachta a nascadh:",
    "Copy" : "Cóipeáil",
    "Output in JSON" : "Aschur in JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Scipeáil ar an rannán aipeanna (seolfar iarratas seachtrach chuig an siopa aipeanna san áireamh)",
    "Skip server update" : "Léim ar nuashonrú an fhreastalaí",
    "To use an access token, please generate one then set it using the following command:" : "Chun comhartha rochtana a úsáid, giniúint ceann agus ansin socraigh é ag baint úsáide as an ordú seo a leanas le do thoil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ansin cuir an comhartha leis an gceanntásc \"NC-Token\" agus an URL thuas á cheistiú.",
    "DNS:" : "DNS:",
    "Skip app updates (including app updates will send an external request to the app store)" : "Léim ar nuashonruithe aipeanna (seolfaidh nuashonruithe aipeanna iarratas seachtrach chuig an siopa aip san áireamh)"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
